==> vala-0.7.3.tar.bz2: vala-0.7.3/codegen/valastructregisterfunction.c <==
/* valastructregisterfunction.vala
 *
 * Copyright (C) 2008  Jürg Billeter
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.

 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 *
 * Author:
 * 	Jürg Billeter <j@bitron.ch>
 */

#include <glib.h>
#include <glib-object.h>
#include <vala.h>
#include <stdlib.h>
#include <string.h>
#include <valaccode.h>


#define VALA_TYPE_TYPEREGISTER_FUNCTION (vala_typeregister_function_get_type ())
#define VALA_TYPEREGISTER_FUNCTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_TYPEREGISTER_FUNCTION, ValaTypeRegisterFunction))
#define VALA_TYPEREGISTER_FUNCTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_TYPEREGISTER_FUNCTION, ValaTypeRegisterFunctionClass))
#define VALA_IS_TYPEREGISTER_FUNCTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_TYPEREGISTER_FUNCTION))
#define VALA_IS_TYPEREGISTER_FUNCTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_TYPEREGISTER_FUNCTION))
#define VALA_TYPEREGISTER_FUNCTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_TYPEREGISTER_FUNCTION, ValaTypeRegisterFunctionClass))

typedef struct _ValaTypeRegisterFunction ValaTypeRegisterFunction;
typedef struct _ValaTypeRegisterFunctionClass ValaTypeRegisterFunctionClass;
typedef struct _ValaTypeRegisterFunctionPrivate ValaTypeRegisterFunctionPrivate;

#define VALA_TYPE_STRUCT_REGISTER_FUNCTION (vala_struct_register_function_get_type ())
#define VALA_STRUCT_REGISTER_FUNCTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_STRUCT_REGISTER_FUNCTION, ValaStructRegisterFunction))
#define VALA_STRUCT_REGISTER_FUNCTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_STRUCT_REGISTER_FUNCTION, ValaStructRegisterFunctionClass))
#define VALA_IS_STRUCT_REGISTER_FUNCTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_STRUCT_REGISTER_FUNCTION))
#define VALA_IS_STRUCT_REGISTER_FUNCTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_STRUCT_REGISTER_FUNCTION))
#define VALA_STRUCT_REGISTER_FUNCTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_STRUCT_REGISTER_FUNCTION, ValaStructRegisterFunctionClass))

typedef struct _ValaStructRegisterFunction ValaStructRegisterFunction;
typedef struct _ValaStructRegisterFunctionClass ValaStructRegisterFunctionClass;
typedef struct _ValaStructRegisterFunctionPrivate ValaStructRegisterFunctionPrivate;

/**
 * C function to register a type at runtime.
 */
struct _ValaTypeRegisterFunction {
	GTypeInstance parent_instance;
	volatile int ref_count;
	ValaTypeRegisterFunctionPrivate * priv;
};

struct _ValaTypeRegisterFunctionClass {
	GTypeClass parent_class;
	void (*finalize) (ValaTypeRegisterFunction *self);
	ValaTypeSymbol* (*get_type_declaration) (ValaTypeRegisterFunction* self);
	char* (*get_type_struct_name) (ValaTypeRegisterFunction* self);
	char* (*get_base_init_func_name) (ValaTypeRegisterFunction* self);
	char* (*get_class_finalize_func_name) (ValaTypeRegisterFunction* self);
	char* (*get_base_finalize_func_name) (ValaTypeRegisterFunction* self);
	char* (*get_class_init_func_name) (ValaTypeRegisterFunction* self);
	char* (*get_instance_struct_size) (ValaTypeRegisterFunction* self);
	char* (*get_instance_init_func_name) (ValaTypeRegisterFunction* self);
	char* (*get_parent_type_name) (ValaTypeRegisterFunction* self);
	char* (*get_gtype_value_table_init_function_name) (ValaTypeRegisterFunction* self);
	char* (*get_gtype_value_table_peek_pointer_function_name) (ValaTypeRegisterFunction* self);
	char* (*get_gtype_value_table_free_function_name) (ValaTypeRegisterFunction* self);
	char* (*get_gtype_value_table_copy_function_name) (ValaTypeRegisterFunction* self);
	char* (*get_gtype_value_table_lcopy_value_function_name) (ValaTypeRegisterFunction* self);
	char* (*get_gtype_value_table_collect_value_function_name) (ValaTypeRegisterFunction* self);
	char* (*get_type_flags) (ValaTypeRegisterFunction* self);
	ValaCCodeFragment* (*get_type_interface_init_declaration) (ValaTypeRegisterFunction* self);
	ValaCCodeFragment* (*get_type_interface_init_statements) (ValaTypeRegisterFunction* self);
	ValaSymbolAccessibility (*get_accessibility) (ValaTypeRegisterFunction* self);
};

/**
 * C function to register a class at runtime.
 */
struct _ValaStructRegisterFunction {
	ValaTypeRegisterFunction parent_instance;
	ValaStructRegisterFunctionPrivate * priv;
};

struct _ValaStructRegisterFunctionClass {
	ValaTypeRegisterFunctionClass parent_class;
};

struct _ValaStructRegisterFunctionPrivate {
	ValaStruct* _struct_reference;
};



gpointer vala_typeregister_function_ref (gpointer instance);
void vala_typeregister_function_unref (gpointer instance);
GParamSpec* vala_param_spec_typeregister_function (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void vala_value_set_typeregister_function (GValue* value, gpointer v_object);
gpointer vala_value_get_typeregister_function (const GValue* value);
GType vala_typeregister_function_get_type (void);
GType vala_struct_register_function_get_type (void);
#define VALA_STRUCT_REGISTER_FUNCTION_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_STRUCT_REGISTER_FUNCTION, ValaStructRegisterFunctionPrivate))
enum  {
	VALA_STRUCT_REGISTER_FUNCTION_DUMMY_PROPERTY
};
void vala_struct_register_function_set_struct_reference (ValaStructRegisterFunction* self, ValaStruct* value);
void vala_typeregister_function_set_context (ValaTypeRegisterFunction* self, ValaCodeContext* value);
ValaStructRegisterFunction* vala_struct_register_function_new (ValaStruct* st, ValaCodeContext* context);
ValaStructRegisterFunction* vala_struct_register_function_construct (GType object_type, ValaStruct* st, ValaCodeContext* context);
ValaStructRegisterFunction* vala_struct_register_function_new (ValaStruct* st, ValaCodeContext* context);
ValaStruct* vala_struct_register_function_get_struct_reference (ValaStructRegisterFunction* self);
static ValaTypeSymbol* vala_struct_register_function_real_get_type_declaration (ValaTypeRegisterFunction* base);
static ValaSymbolAccessibility vala_struct_register_function_real_get_accessibility (ValaTypeRegisterFunction* base);
static ValaCCodeFragment* vala_struct_register_function_real_get_type_interface_init_statements (ValaTypeRegisterFunction* base);
static gpointer vala_struct_register_function_parent_class = NULL;
static void vala_struct_register_function_finalize (ValaTypeRegisterFunction* obj);



/**
 * Creates a new C function to register the specified class at runtime.
 *
 * @param cl a class
 * @return   newly created class register function
 */
ValaStructRegisterFunction* vala_struct_register_function_construct (GType object_type, ValaStruct* st, ValaCodeContext* context) {
	ValaStructRegisterFunction* self;
	g_return_val_if_fail (st != NULL, NULL);
	g_return_val_if_fail (context != NULL, NULL);
	self = (ValaStructRegisterFunction*) g_type_create_instance (object_type);
	vala_struct_register_function_set_struct_reference (self, st);
	vala_typeregister_function_set_context ((ValaTypeRegisterFunction*) self, context);
	return self;
}


ValaStructRegisterFunction* vala_struct_register_function_new (ValaStruct* st, ValaCodeContext* context) {
	return vala_struct_register_function_construct (VALA_TYPE_STRUCT_REGISTER_FUNCTION, st, context);
}


static ValaTypeSymbol* vala_struct_register_function_real_get_type_declaration (ValaTypeRegisterFunction* base) {
	ValaStructRegisterFunction * self;
	ValaTypeSymbol* _tmp0_;
	self = (ValaStructRegisterFunction*) base;
	_tmp0_ = NULL;
	return (_tmp0_ = (ValaTypeSymbol*) self->priv->_struct_reference, (_tmp0_ == NULL) ? NULL : vala_code_node_ref (_tmp0_));
}


static ValaSymbolAccessibility vala_struct_register_function_real_get_accessibility (ValaTypeRegisterFunction* base) {
	ValaStructRegisterFunction * self;
	self = (ValaStructRegisterFunction*) base;
	return vala_symbol_get_access ((ValaSymbol*) self->priv->_struct_reference);
}


static ValaCCodeFragment* vala_struct_register_function_real_get_type_interface_init_statements (ValaTypeRegisterFunction* base) {
	ValaStructRegisterFunction * self;
	self = (ValaStructRegisterFunction*) base;
	return vala_ccode_fragment_new ();
}


ValaStruct* vala_struct_register_function_get_struct_reference (ValaStructRegisterFunction* self) {
	g_return_val_if_fail (self != NULL, NULL);
	return self->priv->_struct_reference;
}


void vala_struct_register_function_set_struct_reference (ValaStructRegisterFunction* self, ValaStruct* value) {
	g_return_if_fail (self != NULL);
	self->priv->_struct_reference = value;
}


static void vala_struct_register_function_class_init (ValaStructRegisterFunctionClass * klass) {
	vala_struct_register_function_parent_class = g_type_class_peek_parent (klass);
	VALA_TYPEREGISTER_FUNCTION_CLASS (klass)->finalize = vala_struct_register_function_finalize;
	g_type_class_add_private (klass, sizeof (ValaStructRegisterFunctionPrivate));
	VALA_TYPEREGISTER_FUNCTION_CLASS (klass)->get_type_declaration = vala_struct_register_function_real_get_type_declaration;
	VALA_TYPEREGISTER_FUNCTION_CLASS (klass)->get_accessibility = vala_struct_register_function_real_get_accessibility;
	VALA_TYPEREGISTER_FUNCTION_CLASS (klass)->get_type_interface_init_statements = vala_struct_register_function_real_get_type_interface_init_statements;
}


static void vala_struct_register_function_instance_init (ValaStructRegisterFunction * self) {
	self->priv = VALA_STRUCT_REGISTER_FUNCTION_GET_PRIVATE (self);
}


static void vala_struct_register_function_finalize (ValaTypeRegisterFunction* obj) {
	ValaStructRegisterFunction * self;
	self = VALA_STRUCT_REGISTER_FUNCTION (obj);
	VALA_TYPEREGISTER_FUNCTION_CLASS (vala_struct_register_function_parent_class)->finalize (obj);
}


GType vala_struct_register_function_get_type (void) {
	static GType vala_struct_register_function_type_id = 0;
	if (vala_struct_register_function_type_id == 0) {
		static const GTypeInfo g_define_type_info = { sizeof (ValaStructRegisterFunctionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_struct_register_function_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaStructRegisterFunction), 0, (GInstanceInitFunc) vala_struct_register_function_instance_init, NULL };
		vala_struct_register_function_type_id = g_type_register_static (VALA_TYPE_TYPEREGISTER_FUNCTION, "ValaStructRegisterFunction", &g_define_type_info, 0);
	}
	return vala_struct_register_function_type_id;
}

==> vala-0.7.5.tar.bz2: vala-0.7.5/codegen/valastructregisterfunction.c <==
/* valastructregisterfunction.vala
 *
 * Copyright (C) 2008  Jürg Billeter
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.

 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 *
 * Author:
 * 	Jürg Billeter <j@bitron.ch>
 */

#include <glib.h>
#include <glib-object.h>
#include <vala.h>
#include <stdlib.h>
#include <string.h>
#include <valaccode.h>


#define VALA_TYPE_TYPEREGISTER_FUNCTION (vala_typeregister_function_get_type ())
#define VALA_TYPEREGISTER_FUNCTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_TYPEREGISTER_FUNCTION, ValaTypeRegisterFunction))
#define VALA_TYPEREGISTER_FUNCTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_TYPEREGISTER_FUNCTION, ValaTypeRegisterFunctionClass))
#define VALA_IS_TYPEREGISTER_FUNCTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_TYPEREGISTER_FUNCTION))
#define VALA_IS_TYPEREGISTER_FUNCTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_TYPEREGISTER_FUNCTION))
#define VALA_TYPEREGISTER_FUNCTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_TYPEREGISTER_FUNCTION, ValaTypeRegisterFunctionClass))

typedef struct _ValaTypeRegisterFunction ValaTypeRegisterFunction;
typedef struct _ValaTypeRegisterFunctionClass ValaTypeRegisterFunctionClass;
typedef struct _ValaTypeRegisterFunctionPrivate ValaTypeRegisterFunctionPrivate;

#define VALA_TYPE_STRUCT_REGISTER_FUNCTION (vala_struct_register_function_get_type ())
#define VALA_STRUCT_REGISTER_FUNCTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_STRUCT_REGISTER_FUNCTION, ValaStructRegisterFunction))
#define VALA_STRUCT_REGISTER_FUNCTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_STRUCT_REGISTER_FUNCTION, ValaStructRegisterFunctionClass))
#define VALA_IS_STRUCT_REGISTER_FUNCTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_STRUCT_REGISTER_FUNCTION))
#define VALA_IS_STRUCT_REGISTER_FUNCTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_STRUCT_REGISTER_FUNCTION))
#define VALA_STRUCT_REGISTER_FUNCTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_STRUCT_REGISTER_FUNCTION, ValaStructRegisterFunctionClass))

typedef struct _ValaStructRegisterFunction ValaStructRegisterFunction;
typedef struct _ValaStructRegisterFunctionClass ValaStructRegisterFunctionClass;
typedef struct _ValaStructRegisterFunctionPrivate ValaStructRegisterFunctionPrivate;

/**
 * C function to register a type at runtime.
 */
struct _ValaTypeRegisterFunction {
	GTypeInstance parent_instance;
	volatile int ref_count;
	ValaTypeRegisterFunctionPrivate * priv;
};

struct _ValaTypeRegisterFunctionClass {
	GTypeClass parent_class;
	void (*finalize) (ValaTypeRegisterFunction *self);
	ValaTypeSymbol* (*get_type_declaration) (ValaTypeRegisterFunction* self);
	char* (*get_type_struct_name) (ValaTypeRegisterFunction* self);
	char* (*get_base_init_func_name) (ValaTypeRegisterFunction* self);
	char* (*get_class_finalize_func_name) (ValaTypeRegisterFunction* self);
	char* (*get_base_finalize_func_name) (ValaTypeRegisterFunction* self);
	char* (*get_class_init_func_name) (ValaTypeRegisterFunction* self);
	char* (*get_instance_struct_size) (ValaTypeRegisterFunction* self);
	char* (*get_instance_init_func_name) (ValaTypeRegisterFunction* self);
	char* (*get_parent_type_name) (ValaTypeRegisterFunction* self);
	char* (*get_gtype_value_table_init_function_name) (ValaTypeRegisterFunction* self);
	char* (*get_gtype_value_table_peek_pointer_function_name) (ValaTypeRegisterFunction* self);
	char* (*get_gtype_value_table_free_function_name) (ValaTypeRegisterFunction* self);
	char* (*get_gtype_value_table_copy_function_name) (ValaTypeRegisterFunction* self);
	char* (*get_gtype_value_table_lcopy_value_function_name) (ValaTypeRegisterFunction* self);
	char* (*get_gtype_value_table_collect_value_function_name) (ValaTypeRegisterFunction* self);
	char* (*get_type_flags) (ValaTypeRegisterFunction* self);
	ValaCCodeFragment* (*get_type_interface_init_declaration) (ValaTypeRegisterFunction* self);
	ValaCCodeFragment* (*get_type_interface_init_statements) (ValaTypeRegisterFunction* self);
	ValaSymbolAccessibility (*get_accessibility) (ValaTypeRegisterFunction* self);
};

/**
 * C function to register a class at runtime.
 */
struct _ValaStructRegisterFunction {
	ValaTypeRegisterFunction parent_instance;
	ValaStructRegisterFunctionPrivate * priv;
};

struct _ValaStructRegisterFunctionClass {
	ValaTypeRegisterFunctionClass parent_class;
};

struct _ValaStructRegisterFunctionPrivate {
	ValaStruct* _struct_reference;
};


static gpointer vala_struct_register_function_parent_class = NULL;

gpointer vala_typeregister_function_ref (gpointer instance);
void vala_typeregister_function_unref (gpointer instance);
GParamSpec* vala_param_spec_typeregister_function (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void vala_value_set_typeregister_function (GValue* value, gpointer v_object);
gpointer vala_value_get_typeregister_function (const GValue* value);
GType vala_typeregister_function_get_type (void);
GType vala_struct_register_function_get_type (void);
#define VALA_STRUCT_REGISTER_FUNCTION_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_STRUCT_REGISTER_FUNCTION, ValaStructRegisterFunctionPrivate))
enum  {
	VALA_STRUCT_REGISTER_FUNCTION_DUMMY_PROPERTY
};
void vala_struct_register_function_set_struct_reference (ValaStructRegisterFunction* self, ValaStruct* value);
void vala_typeregister_function_set_context (ValaTypeRegisterFunction* self, ValaCodeContext* value);
ValaStructRegisterFunction* vala_struct_register_function_new (ValaStruct* st, ValaCodeContext* context);
ValaStructRegisterFunction* vala_struct_register_function_construct (GType object_type, ValaStruct* st, ValaCodeContext* context);
ValaStruct* vala_struct_register_function_get_struct_reference (ValaStructRegisterFunction* self);
static ValaTypeSymbol* vala_struct_register_function_real_get_type_declaration (ValaTypeRegisterFunction* base);
static ValaSymbolAccessibility vala_struct_register_function_real_get_accessibility (ValaTypeRegisterFunction* base);
static ValaCCodeFragment* vala_struct_register_function_real_get_type_interface_init_statements (ValaTypeRegisterFunction* base);
static void vala_struct_register_function_finalize (ValaTypeRegisterFunction* obj);



/**
 * Creates a new C function to register the specified class at runtime.
 *
 * @param cl a class
 * @return   newly created class register function
 */
ValaStructRegisterFunction* vala_struct_register_function_construct (GType object_type, ValaStruct* st, ValaCodeContext* context) {
	ValaStructRegisterFunction* self;
	g_return_val_if_fail (st != NULL, NULL);
	g_return_val_if_fail (context != NULL, NULL);
	self = (ValaStructRegisterFunction*) g_type_create_instance (object_type);
	vala_struct_register_function_set_struct_reference (self, st);
	vala_typeregister_function_set_context ((ValaTypeRegisterFunction*) self, context);
	return self;
}


ValaStructRegisterFunction* vala_struct_register_function_new (ValaStruct* st, ValaCodeContext* context) {
	return vala_struct_register_function_construct (VALA_TYPE_STRUCT_REGISTER_FUNCTION, st, context);
}


static ValaTypeSymbol* vala_struct_register_function_real_get_type_declaration (ValaTypeRegisterFunction* base) {
	ValaStructRegisterFunction * self;
	ValaTypeSymbol* result;
	ValaTypeSymbol* _tmp0_;
	self = (ValaStructRegisterFunction*) base;
	_tmp0_ = NULL;
	result = (_tmp0_ = (ValaTypeSymbol*) self->priv->_struct_reference, (_tmp0_ == NULL) ? NULL : vala_code_node_ref (_tmp0_));
	return result;
}


static ValaSymbolAccessibility vala_struct_register_function_real_get_accessibility (ValaTypeRegisterFunction* base) {
	ValaStructRegisterFunction * self;
	ValaSymbolAccessibility result;
	self = (ValaStructRegisterFunction*) base;
	result = vala_symbol_get_access ((ValaSymbol*) self->priv->_struct_reference);
	return result;
}


static ValaCCodeFragment* vala_struct_register_function_real_get_type_interface_init_statements (ValaTypeRegisterFunction* base) {
	ValaStructRegisterFunction * self;
	ValaCCodeFragment* result;
	self = (ValaStructRegisterFunction*) base;
	result = vala_ccode_fragment_new ();
	return result;
}


ValaStruct* vala_struct_register_function_get_struct_reference (ValaStructRegisterFunction* self) {
	ValaStruct* result;
	g_return_val_if_fail (self != NULL, NULL);
	result = self->priv->_struct_reference;
	return result;
}


void vala_struct_register_function_set_struct_reference (ValaStructRegisterFunction* self, ValaStruct* value) {
	g_return_if_fail (self != NULL);
	self->priv->_struct_reference = value;
}


static void vala_struct_register_function_class_init (ValaStructRegisterFunctionClass * klass) {
	vala_struct_register_function_parent_class = g_type_class_peek_parent (klass);
	VALA_TYPEREGISTER_FUNCTION_CLASS (klass)->finalize = vala_struct_register_function_finalize;
	g_type_class_add_private (klass, sizeof (ValaStructRegisterFunctionPrivate));
	VALA_TYPEREGISTER_FUNCTION_CLASS (klass)->get_type_declaration = vala_struct_register_function_real_get_type_declaration;
	VALA_TYPEREGISTER_FUNCTION_CLASS (klass)->get_accessibility = vala_struct_register_function_real_get_accessibility;
	VALA_TYPEREGISTER_FUNCTION_CLASS (klass)->get_type_interface_init_statements = vala_struct_register_function_real_get_type_interface_init_statements;
}


static void vala_struct_register_function_instance_init (ValaStructRegisterFunction * self) {
	self->priv = VALA_STRUCT_REGISTER_FUNCTION_GET_PRIVATE (self);
}


static void vala_struct_register_function_finalize (ValaTypeRegisterFunction* obj) {
	ValaStructRegisterFunction * self;
	self = VALA_STRUCT_REGISTER_FUNCTION (obj);
	VALA_TYPEREGISTER_FUNCTION_CLASS (vala_struct_register_function_parent_class)->finalize (obj);
}


GType vala_struct_register_function_get_type (void) {
	static GType vala_struct_register_function_type_id = 0;
	if (vala_struct_register_function_type_id == 0) {
		static const GTypeInfo g_define_type_info = { sizeof (ValaStructRegisterFunctionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_struct_register_function_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaStructRegisterFunction), 0, (GInstanceInitFunc) vala_struct_register_function_instance_init, NULL };
		vala_struct_register_function_type_id = g_type_register_static (VALA_TYPE_TYPEREGISTER_FUNCTION, "ValaStructRegisterFunction", &g_define_type_info, 0);
	}
	return vala_struct_register_function_type_id;
}
